@@ -1,7 +1,7 @@
 //! Macros for poem
 
 #![doc(html_favicon_url = "https://poem.rs/assets/favicon.ico")]
-#![doc(html_logo_url = "https://poem.rs/assets/logo.png")]
+#![doc(html_logo_url = "https://poem.rs/en/assets/logo.png")]
 #![forbid(unsafe_code)]
 #![deny(private_in_public, unreachable_pub)]
 #![cfg_attr(docsrs, feature(doc_cfg))]
